@@ -25,7 +25,7 @@ __copyright__ = "Copyright 2011, Giridhar Pemmasani"
 __contributors__ = []
 __maintainer__ = "Giridhar Pemmasani (pgiri@yahoo.com)"
 __license__ = "Apache 2.0"
-__url__ = "http://dispy.sourceforge.net"
+__url__ = "https://dispy.org"
 __status__ = "Production"
 __version__ = dispy._dispy_version
 __all__ = []
